<?php
namespace Aws\BCMPricingCalculator\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Billing and Cost Management Pricing Calculator** service.
 */
class BCMPricingCalculatorException extends AwsException {}
